# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## NAG.ERD.get_chassis_id
##----------------------------------------------------------------------
## Copyright (C) 2007-2014 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## Python modules
import lxml.html
## NOC modules
from noc.sa.script import Script as NOCScript
from noc.sa.interfaces import IGetChassisID


class Script(NOCScript):
    name = "NAG.ERD.get_chassis_id"
    implements = [IGetChassisID]
    cache = True

    def execute(self):
        # Try SNMP first
        if self.snmp and self.access_profile.snmp_ro:
            try:
                mac = self.snmp.get("1.3.6.1.2.1.2.2.1.6.0", cached=True)
                return {
                        "first_chassis_mac": mac,
                        "last_chassis_mac": mac
                        }
            except self.snmp.TimeOutError:
                pass

        # Fallback to HTTP
        root = lxml.html.fromstring(self.http.get("/ipconf=1"))
        mac = root.find_class('TS2')[0].getchildren()[0][2].text

        return {
                "first_chassis_mac": mac,
                "last_chassis_mac": mac
                }
