# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## NAG.ERD.get_interfaces
##----------------------------------------------------------------------
## Copyright (C) 2007-2014 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## Python modules
import lxml.html
# NOC modules
from noc.sa.script import Script as NOCScript
from noc.sa.interfaces import IGetInterfaces
from noc.sa.interfaces.base import IPv4Parameter
from noc.lib.ip import IPv4


class Script(NOCScript):
    name = "NAG.ERD.get_interfaces"
    implements = [IGetInterfaces]
    cached = True

    def execute(self):
        # Try SNMP first
        if self.snmp and self.access_profile.snmp_ro:
            try:
                mac = self.snmp.get("1.3.6.1.2.1.2.2.1.6.0", cached = True)
                mac = ":".join(["%02x" % ord(c) for c in mac])
                description = self.snmp.get("1.3.6.1.2.1.1.5.0", cached = True)
                ip = self.snmp.get("1.3.6.1.2.1.4.20.1.1.0", cached = True)
                ip = ".".join(["%02x" % int(str(ord(c)), 16) for c in ip])
#                ip = IPv4Parameter().clean(ip)
#                mask = self.snmp.get("1.3.6.1.2.1.2.2.1.6.0", cached = True)
#                mask = IPv4.netmask_to_len(mask)
                mask = 24

                iface = {
                    "name": 'Et1',
                    "admin_status": True,
                    "oper_status": True,
                    "type": "physical",
                    "description": description,
                    "mac": mac,
                    "subinterfaces": [{
                        "name": 'Et1',
                        "admin_status": True,
                        "oper_status": True,
                        "type": "physical",
                        "description": description,
                        "mac": mac,
                        "enabled_afi": ["IPv4"],
                        "ipv4_addresses": ["%s/%s" % (ip, mask)]
                        }]
                    }
                return [{"interfaces": [iface]}]
            except self.snmp.TimeOutError:
                pass

        # Fallback to HTTP
        root = lxml.html.fromstring(self.http.get("/main.html"))
        data = root.find_class('TS1')[0].getchildren()
        description = data[0][1].text
        ip = data[9][1].text
#        mask = data[9][1].text
#        mask = IPv4.netmask_to_len(mask)
        mask = 24

        root = lxml.html.fromstring(self.http.get("/ipconf=1"))
        mac = root.find_class('TS2')[0].getchildren()[0][2].text

        iface = {
            "name": 'Et1',
            "admin_status": True,
            "oper_status": True,
            "type": "physical",
            "description": description,
            "mac": mac,
            "subinterfaces": [{
                "name": 'Et1',
                "admin_status": True,
                "oper_status": True,
                "type": "physical",
                "description": description,
                "mac": mac,
                "enabled_afi": ["IPv4"],
                "ipv4_addresses": ["%s/%s" % (ip, mask)]
                }]
            }
        return [{"interfaces": [iface]}]
