# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## NAG.ERD.get_inventory
##----------------------------------------------------------------------
## Copyright (C) 2007-2014 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## Python modules
import lxml.html
## NOC modules
from noc.sa.script import Script as NOCScript
from noc.sa.interfaces import IGetInventory


class Script(NOCScript):
    name = "NAG.ERD.get_inventory"
    implements = [IGetInventory]
    cache = True

    def execute(self):
        # Try SNMP first
        if self.snmp and self.access_profile.snmp_ro:
            try:
                platform = self.snmp.get("1.3.6.1.2.1.1.2.0", cached=True)
                platform = self.profile.nag_erd_plat[platform.split('.')[8]]
                description = self.snmp.get("1.3.6.1.2.1.1.5.0", cached=True)
                return [{
                    "type": "CHASSIS",
                    "number": "1",
                    "builtin": False,
                    "vendor": "NAG",
                    "part_no": ["ERD-" + platform],
                    "description": description
                }]
            except self.snmp.TimeOutError:
                pass

        # Fallback to HTTP
        root = lxml.html.fromstring(self.http.get("/top.html"))
        platform = root.text_content().split('-')[1]

        root = lxml.html.fromstring(self.http.get("/main.html"))
        description = root.find_class('TS1')[0].getchildren()[0][1].text

        return [{
            "type": "CHASSIS",
            "number": "1",
            "builtin": False,
            "vendor": "NAG",
            "part_no": ["ERD-" + platform],
            "description": description
        }]
