# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## NAG.ERD.get_version
##----------------------------------------------------------------------
## Copyright (C) 2007-2014 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## Python modules
import lxml.html
## NOC modules
from noc.sa.script import Script as NOCScript
from noc.sa.interfaces import IGetVersion


class Script(NOCScript):
    name = "NAG.ERD.get_version"
    implements = [IGetVersion]
    cache = True

    def execute(self):
        # Try SNMP first
        if self.snmp and self.access_profile.snmp_ro:
            try:
                platform = self.snmp.get("1.3.6.1.2.1.1.2.0", cached=True)
                platform = self.profile.nag_erd_plat[platform.split('.')[8]]
                version = self.snmp.get("1.3.6.1.2.1.1.1.0", cached=True)
                version = version[4:]
                return {
                        "vendor": "NAG",
                        "platform": "ERD-" + platform,
                        "version": version,
                        }
            except self.snmp.TimeOutError:
                pass

        # Fallback to HTTP
        root = lxml.html.fromstring(self.http.get("/top.html"))
        platform = root.text_content().split('-')[1]

        root = lxml.html.fromstring(self.http.get("/main.html"))
        version = root.find_class('TS1')[0].getchildren()[1][1].text

        return {
                "vendor": "NAG",
                "platform": "ERD-" + platform,
                "version": version,
                }
